/*
 * This source code (.java) file is Copyright  2000 Artima Software, Inc. All rights reserved. 
 * This file accompanies the Jini Place Service Draft Specification, written by Bill
 * Venners and published on the World Wide Web at:
 * 
 *     http://www.artima.com/jini/cyberspace/DraftSpec.html,
 *
 * This source file may not be copied, modified, or redistributed EXCEPT as allowed
 * by the following statements: From August 11, 2000 through December 31, 2000, you may
 * copy and/or modify these files to test and experiment with the Place API,
 * described in the Jini Place Service Draft Specification. Any bug fixes must be given
 * back to Artima Software, Inc. You may not redistribute this file or any binary (such
 * as .class) files generated from this file. You may not distribute modified versions
 * this files or any binary (such as .class) files generated from modified versions of
 * this file. You may not remove this copyright notice. You may not use this file in
 * printed media without the express permission of Bill Venners. And if that weren't
 * enough, you must destroy all copies of this file, and any binary (such as
 * .class) files generated from this file, by December 31, 2000.
 *
 * ARTIMA SOFTWARE, INC. MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THIS SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR PARTICULAR PURPOSE, OR NON-INFRINGEMENT.
 * BILL VENNERS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY A LICENSEE AS A RESULT
 * OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
*/
package net.artima.place;

import java.io.Serializable;
import java.rmi.RemoteException;
import java.util.Set;
import java.util.Collection;

/**
* Represents a map of links to resources on the network.
*/
public interface LinkMap extends Serializable {

    /**
    * Returns the <CODE>Link</CODE> value to which this <CODE>LinkMap</CODE> maps
    * the specified <CODE>Object</CODE> key.
    */
    Link get(Object key) throws RemoteException;

    /**
    * Returns <CODE>true</CODE> if this <CODE>LinkMap</CODE> contains a mapping for
    * the specified key.
    */
    boolean containsKey(Object key) throws RemoteException;

    /**
    * Returns <CODE>true</CODE> if this <CODE>LinkMap</CODE> maps one or more keys
    * to the specified value.
    */
    boolean containsValue(Link value) throws RemoteException;

    /**
    * Returns <CODE>true</CODE> if this map contains no key-value mappings.
    */
    boolean isEmpty() throws RemoteException;

    /**
    * Returns an unmodifiable set view of the keys contained in this map.
    */
    Set keySet() throws RemoteException;

    /**
    * Returns the number of key-value mappings in this map.
    */
    int size() throws RemoteException;

    /**
    * Returns a collection view of the values contained in this <CODE>LinkMap</CODE>.
    */
    Collection values() throws RemoteException;
}

