/*
 * This source code (.java) file is Copyright  2000 Artima Software, Inc. All rights reserved. 
 * This file accompanies the Jini Place Service Draft Specification, written by Bill
 * Venners and published on the World Wide Web at:
 * 
 *     http://www.artima.com/jini/cyberspace/DraftSpec.html,
 *
 * This source file may not be copied, modified, or redistributed EXCEPT as allowed
 * by the following statements: From August 11, 2000 through December 31, 2000, you may
 * copy and/or modify these files to test and experiment with the Place API,
 * described in the Jini Place Service Draft Specification. Any bug fixes must be given
 * back to Artima Software, Inc. You may not redistribute this file or any binary (such
 * as .class) files generated from this file. You may not distribute modified versions
 * this files or any binary (such as .class) files generated from modified versions of
 * this file. You may not remove this copyright notice. You may not use this file in
 * printed media without the express permission of Bill Venners. And if that weren't
 * enough, you must destroy all copies of this file, and any binary (such as
 * .class) files generated from this file, by December 31, 2000.
 *
 * ARTIMA SOFTWARE, INC. MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THIS SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR PARTICULAR PURPOSE, OR NON-INFRINGEMENT.
 * BILL VENNERS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY A LICENSEE AS A RESULT
 * OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
*/
package net.artima.place;

import java.util.Locale;
import java.io.Serializable;
import java.io.InputStream;
import java.net.URL;

/**
* A bundle of information about a resource represented by a <CODE>Link</CODE>.
*/
public interface ResourceInfo extends Serializable {

    /**
    * Constant to indicate a 16 x 16 color icon.
    * (Same value as java.beans.BeanInfo.ICON_COLOR_16x16.)
    */
    int ICON_COLOR_16x16 = 1;

    /**
    * Constant to indicate a 32 x 32 color icon.
    * (Same value as java.beans.BeanInfo.ICON_COLOR_32x32.)
    */
    int ICON_COLOR_32x32 = 2;

    /**
    * Constant to indicate a 16 x 16 monochrome icon.
    * (Same value as java.beans.BeanInfo.ICON_MONO_16x16.)
    */
    int ICON_MONO_16x16 = 3;

    /**
    * Constant to indicate a 32 x 32 monochrome icon.
    * (Same value as java.beans.BeanInfo.ICON_MONO_32x32.)
    */
    int ICON_MONO_32x32 = 4;

    /**
    * Returns an array of locales supported by this ResourceInfo.
    * In other words, this ResourceInfo will be able to return user
    * oriented data for each locale in the returned array.
    */
    Locale[] getSupportedLocales();

    /**
    * Gets the name of this resource, suitable for presentation to users,.
    * under the current locale.
    */
    String getName();

    /**
    * Gets the name of this resource, suitable for presentation to users.
    * under the specified locale.
    */
    String getName(Locale locale);

    /**
    * Gets a set of keywords for this resource, suitable for presentation to users,
    * under the current locale. Keywords are used by search engines to index
    * the resource.
    */
    String[] getKeywords();

    /**
    * Gets a set of keywords for this resource, suitable for presentation to users,
    * under the specified locale. Keywords are used by search engines to index
    * the resource.
    */
    String[] getKeywords(Locale locale);

    /**
    * Gets a short description for this resource, suitable for presentation to users,
    * under the current locale.
    */
    String getDescription();

    /**
    * Gets a short description for this resource, suitable for presentation to users,
    * under the specified locale.
    */
    String getDescription(Locale locale);

    /**
    * Gets a URL for the image file of an icon for this resource, suitable for presentation to users,
    * under the current locale. (The image file is likely either a GIF
    * or JPG file, but could be any image file format.) The valid parameter values are the same as for
    * the getIcon method of java.beans.BeanInfo, which for convenience are also declared in this
    * interface: ICON_COLOR_16x16, ICON_COLOR_32x32, ICON_MONO_16x16, ICON_MONO_32x32.
    */
    URL getIconImageFile(int iconKind);

    /**
    * Gets an InputStream for the image file of an icon for this resource, suitable for presentation to users,
    * under the current locale. (The image file is likely either a GIF
    * or JPG file, but could be any image file format.) The valid parameter values are the same as for
    * the getIcon method of java.beans.BeanInfo, which for convenience are also declared in this
    * interface: ICON_COLOR_16x16, ICON_COLOR_32x32, ICON_MONO_16x16, ICON_MONO_32x32.
    */
    InputStream getIconImageFileAsStream(int iconKind);

    /**
    * Gets a URL for the image file of an icon for this resource, suitable for presentation to users,
    * under the specified locale. (The image file is likely either a GIF
    * or JPG file, but could be any image file format.) The valid parameter values are the same as for
    * the getIcon method of java.beans.BeanInfo, which for convenience are also declared in this
    * interface: ICON_COLOR_16x16, ICON_COLOR_32x32, ICON_MONO_16x16, ICON_MONO_32x32.
    */
    URL getIconImageFile(Locale locale, int iconKind);

    /**
    * Gets an InputStream for the image file of an icon for this resource, suitable for presentation to users,
    * under the specified locale. (The image file is likely either a GIF
    * or JPG file, but could be any image file format.) The valid parameter values are the same as for
    * the getIcon method of java.beans.BeanInfo, which for convenience are also declared in this
    * interface: ICON_COLOR_16x16, ICON_COLOR_32x32, ICON_MONO_16x16, ICON_MONO_32x32.
    */
    InputStream getIconImageFileAsStream(Locale locale, int iconKind);
}

