/*
 * This source code (.java) file is Copyright  2000 Artima Software, Inc. All rights reserved. 
 * This file accompanies the Jini Place Service Draft Specification, written by Bill
 * Venners and published on the World Wide Web at:
 * 
 *     http://www.artima.com/jini/cyberspace/DraftSpec.html,
 *
 * This source file may not be copied, modified, or redistributed EXCEPT as allowed
 * by the following statements: From August 11, 2000 through December 31, 2000, you may
 * copy and/or modify these files to test and experiment with the Place API,
 * described in the Jini Place Service Draft Specification. Any bug fixes must be given
 * back to Artima Software, Inc. You may not redistribute this file or any binary (such
 * as .class) files generated from this file. You may not distribute modified versions
 * this files or any binary (such as .class) files generated from modified versions of
 * this file. You may not remove this copyright notice. You may not use this file in
 * printed media without the express permission of Bill Venners. And if that weren't
 * enough, you must destroy all copies of this file, and any binary (such as
 * .class) files generated from this file, by December 31, 2000.
 *
 * ARTIMA SOFTWARE, INC. MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THIS SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR PARTICULAR PURPOSE, OR NON-INFRINGEMENT.
 * BILL VENNERS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY A LICENSEE AS A RESULT
 * OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
*/
package net.artima.place;

import java.io.IOException;
import java.io.BufferedOutputStream;
import java.io.ObjectOutputStream;
import java.io.Reader;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.net.Socket;
import net.jini.lookup.entry.UIDescriptor;
import net.jini.core.lookup.ServiceItem;
import net.artima.place.context.UISelector;
import net.artima.place.context.ResourceLauncher;

// TODO: Synchronize this baby

/**
* The service context object produced by <CODE>ServiceContextFactory</CODE>.
*/
class ServiceContext implements UISelector, ResourceLauncher {

    private static final int PORT = 7718;
    private static final int CMD_LAUNCH_URL = 0;

    // The host of the CyberspaceConsole to which "launch URL" commands will
    // be sent.
    private InetAddress consoleHost;

    /**
    * Run a resource with a UI. This is likely done in a
    * separate VM.
    */
    public void launchResource(String url) {

        if (consoleHost == null) {
            // Localhost is the root of all evil
            try {
                consoleHost = InetAddress.getByName(null);
            }
            catch (UnknownHostException uhe) {
                System.out.println("runResourceWithUI(): Unknown Host Exception. Aborting.");
                return;
            }
        }

        System.out.println("runResourceWithUI(" + url + ")");

        try {

            Socket sock = new Socket(consoleHost, PORT);

            try {

                BufferedOutputStream out = new BufferedOutputStream(
                    sock.getOutputStream()
                );

                out.write(CMD_LAUNCH_URL);

                ObjectOutputStream oos = new ObjectOutputStream(out);

                oos.writeObject(url);
                oos.flush();
            }
            finally {
                sock.close();
            }
        }
        catch (IOException ioe) {
            System.out.println("runResourceWithUI(): IO Exception. Aborting.");
            return;
        }

    }

    /**
    * Selects a UI from the UIDescriptors in the passed <CODE>ServiceItem</CODE>.
    */
    public UIDescriptor selectUI(ServiceItem serviceItem) {
        return null;
    }

    /**
    * Selects a UI from the UIDescriptors in the passed array.
    */
    public UIDescriptor selectUI(UIDescriptor[] uiDescriptors) {
        return null;
    }
}
