/*
 * This source code (.java) file is Copyright  2000 Artima Software, Inc. All rights reserved. 
 * This file accompanies the Jini Place Service Draft Specification, written by Bill
 * Venners and published on the World Wide Web at:
 * 
 *     http://www.artima.com/jini/cyberspace/DraftSpec.html,
 *
 * This source file may not be copied, modified, or redistributed EXCEPT as allowed
 * by the following statements: From August 11, 2000 through December 31, 2000, you may
 * copy and/or modify these files to test and experiment with the Place API,
 * described in the Jini Place Service Draft Specification. Any bug fixes must be given
 * back to Artima Software, Inc. You may not redistribute this file or any binary (such
 * as .class) files generated from this file. You may not distribute modified versions
 * this files or any binary (such as .class) files generated from modified versions of
 * this file. You may not remove this copyright notice. You may not use this file in
 * printed media without the express permission of Bill Venners. And if that weren't
 * enough, you must destroy all copies of this file, and any binary (such as
 * .class) files generated from this file, by December 31, 2000.
 *
 * ARTIMA SOFTWARE, INC. MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE SUITABILITY OF
 * THIS SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR PARTICULAR PURPOSE, OR NON-INFRINGEMENT.
 * BILL VENNERS SHALL NOT BE LIABLE FOR ANY DAMAGES SUFFERED BY A LICENSEE AS A RESULT
 * OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR ITS DERIVATIVES.
*/
package net.artima.place;

import java.io.Serializable;
import java.rmi.RemoteException;
import net.artima.place.context.ResourceLauncher;

/**
* Represents a link to a resource on the network.
*/
public class URLLink implements Link {

    private String url;
    private ResourceInfo info;
    private ResourceLauncher context;

    /**
    * Construct a URLLink.
    */
    public URLLink(String url, ResourceInfo info) {

        // NEED TO CHECK THE URL FOR VALID FORMAT
        this.url = url;
        this.info = info;
    }

    private synchronized void getServiceContext() throws LinkActivationException {

        if (context == null) {
            try {
                context = (ResourceLauncher) ServiceContextFactory.getServiceContext();
            }
            catch (ClassCastException e) {
                throw new LinkActivationException();
            }
        }
    }

    /**
    * Get and run the resource with a UI represented by this link.
    */
    public void activate() throws LinkActivationException, RemoteException {

        if (context == null) {
            getServiceContext();
        }
        context.launchResource(url);
    }

    /**
    * Get and return the resource factory that can produce represented by this link.
    */
    public Object getResourceFactory() {
        // Not implemented yet...
        return null;
    }

    /**
    * Get a ResourceInfo class that provides information about this
    * resource suitable for display to users.
    */
    public ResourceInfo getResourceInfo() {
        return info;
    }

    /**
    * Indicates whether or not this <CODE>Link</CODE> can be expressed in terms of a URL.
    */
    public boolean hasURL() {
        return true;
    }

    /**
    * Returns a URL expression of this <CODE>Link</CODE>, if one exists. If this <CODE>Link</CODE>
    * cannot be expressed in terms of a URL, throws <CODE>NoURLAvailableException</CODE>. If
    * hasURL() returns true, this method will return a String URL.
    */
    public String getURL() {
        return url;
    }
}

